import {
  __decorateClass,
  __privateAdd,
  __privateGet,
  __privateMethod
} from "../../../chunks/chunk.QTSIPXV3.js";
var _handleInvalidChange, _renderCheckboxGroupContents, renderCheckboxGroupContents_fn, _renderFieldControlHeader, renderFieldControlHeader_fn, _renderCheckboxes, renderCheckboxes_fn, _handleCheckboxChange, handleCheckboxChange_fn, _computeValue, computeValue_fn, _dispatchInputEvent, dispatchInputEvent_fn, _renderFieldControlFooter, renderFieldControlFooter_fn;
import { localized } from "@lit/localize";
import { property } from "lit/decorators.js";
import { classMap } from "lit/directives/class-map.js";
import { GdsFormControlFooter } from "../../../primitives/form-control-footer/form-control-footer.component.js";
import { GdsFormControlHeader } from "../../../primitives/form-control-header/form-control-header.component.js";
import { gdsCustomElement, html } from "../../../scoping.js";
import { observeLightDOM } from "../../../utils/decorators/index.js";
import { watch } from "../../../utils/decorators/watch.js";
import {
  withLayoutChildProps,
  withMarginProps,
  withSizeXProps
} from "../../../utils/mixins/declarative-layout-mixins.js";
import { GdsFormControlElement } from "../../form/form-control.js";
import { styles } from "./checkbox-group.styles.js";
let CheckboxGroup = class extends GdsFormControlElement {
  constructor() {
    super(...arguments);
    __privateAdd(this, _renderCheckboxGroupContents);
    __privateAdd(this, _renderFieldControlHeader);
    __privateAdd(this, _renderCheckboxes);
    __privateAdd(this, _handleCheckboxChange);
    __privateAdd(this, _computeValue);
    __privateAdd(this, _dispatchInputEvent);
    __privateAdd(this, _renderFieldControlFooter);
    this.size = "large";
    this.direction = "column";
    this.supportingText = "";
    this.showExtendedSupportingText = false;
    __privateAdd(this, _handleInvalidChange, () => {
      this.checkboxes.forEach((checkbox) => {
        checkbox.invalid = this.invalid;
      });
    });
  }
  get value() {
    return this._internalValue || [];
  }
  set value(value) {
    this._internalValue = value;
  }
  /**
   * Returns an array of `<gds-checkbox>` elements in the checkbox group.
   *
   * @readonly
   */
  get checkboxes() {
    return Array.from(
      this.querySelectorAll("[gds-element=gds-checkbox]")
    );
  }
  _getValidityAnchor() {
    return this.checkboxes.pop();
  }
  _handleValueChange() {
    this.checkboxes.forEach((checkbox) => {
      checkbox.checked = this.value.includes(checkbox.value) || false;
    });
  }
  focus() {
    this.checkboxes[0]?.focus();
  }
  connectedCallback() {
    super.connectedCallback();
    this.addEventListener("gds-validity-state", __privateGet(this, _handleInvalidChange));
  }
  render() {
    const classes = {
      "checkbox-group": true,
      "direction-row": this.direction === "row",
      "direction-column": this.direction === "column"
    };
    return html`<div
      role="group"
      id="checkboxgroup"
      class=${classMap(classes)}
      aria-labelledby="group-label"
      aria-describedby="supporting-text extended-supporting-text footer"
      aria-invalid=${this.invalid}
    >
      ${__privateMethod(this, _renderCheckboxGroupContents, renderCheckboxGroupContents_fn).call(this)}
    </div>`;
  }
  _syncOnDOMChange() {
    __privateMethod(this, _computeValue, computeValue_fn).call(this);
  }
};
_handleInvalidChange = new WeakMap();
_renderCheckboxGroupContents = new WeakSet();
renderCheckboxGroupContents_fn = function() {
  const elements = [
    __privateMethod(this, _renderFieldControlHeader, renderFieldControlHeader_fn).call(this),
    __privateMethod(this, _renderCheckboxes, renderCheckboxes_fn).call(this),
    __privateMethod(this, _renderFieldControlFooter, renderFieldControlFooter_fn).call(this)
  ];
  return elements.map((element) => html`${element}`);
};
_renderFieldControlHeader = new WeakSet();
renderFieldControlHeader_fn = function() {
  if (this.label) {
    return html`<gds-form-control-header class="size-${this.size}">
        <label id="group-label" slot="label">${this.label}</label>
        <span slot="supporting-text" id="supporting-text">
          ${this.supportingText}
        </span>
        <slot
          id="extended-supporting-text"
          name="extended-supporting-text"
          slot="extended-supporting-text"
        ></slot>
      </gds-form-control-header>`;
  }
};
_renderCheckboxes = new WeakSet();
renderCheckboxes_fn = function() {
  return html`<div class="content">
      <slot @input=${__privateMethod(this, _handleCheckboxChange, handleCheckboxChange_fn)}></slot>
    </div>`;
};
_handleCheckboxChange = new WeakSet();
handleCheckboxChange_fn = function(e) {
  e && e.stopPropagation();
  __privateMethod(this, _computeValue, computeValue_fn).call(this);
  __privateMethod(this, _dispatchInputEvent, dispatchInputEvent_fn).call(this);
};
_computeValue = new WeakSet();
computeValue_fn = function() {
  const newValue = this.checkboxes.filter((checkbox) => checkbox.checked).map((checkbox) => checkbox.value);
  if (JSON.stringify(newValue) !== JSON.stringify(this.value)) {
    this.value = newValue;
  }
};
_dispatchInputEvent = new WeakSet();
dispatchInputEvent_fn = function() {
  this.updateComplete.then(
    () => this.dispatchEvent(
      new Event("input", {
        bubbles: true,
        composed: true
      })
    )
  );
};
_renderFieldControlFooter = new WeakSet();
renderFieldControlFooter_fn = function() {
  return html`<gds-form-control-footer
      id="footer"
      class="size-${this.size}"
      .validationMessage=${this.invalid && (this.errorMessage || this.validationMessage)}
    >
    </gds-form-control-footer>`;
};
CheckboxGroup.styles = [styles];
__decorateClass([
  property()
], CheckboxGroup.prototype, "size", 2);
__decorateClass([
  property()
], CheckboxGroup.prototype, "direction", 2);
__decorateClass([
  property({ attribute: "supporting-text" })
], CheckboxGroup.prototype, "supportingText", 2);
__decorateClass([
  property({
    attribute: "show-extended-supporting-text",
    type: Boolean,
    reflect: true
  })
], CheckboxGroup.prototype, "showExtendedSupportingText", 2);
__decorateClass([
  property({ type: Array })
], CheckboxGroup.prototype, "value", 1);
__decorateClass([
  watch("value", { waitUntilFirstUpdate: true })
], CheckboxGroup.prototype, "_handleValueChange", 1);
__decorateClass([
  observeLightDOM({
    attributes: true,
    childList: true,
    subtree: true,
    characterData: true
  })
], CheckboxGroup.prototype, "_syncOnDOMChange", 1);
CheckboxGroup = __decorateClass([
  localized()
], CheckboxGroup);
let GdsCheckboxGroup = class extends withLayoutChildProps(
  withMarginProps(withSizeXProps(CheckboxGroup))
) {
};
GdsCheckboxGroup = __decorateClass([
  gdsCustomElement("gds-checkbox-group", {
    dependsOn: [GdsFormControlHeader, GdsFormControlFooter]
  })
], GdsCheckboxGroup);
export {
  GdsCheckboxGroup
};
